# eric7.Preferences.ConfigurationPages.EditorKeywordsPage

Module implementing the editor highlighter keywords configuration page.

### Global Attributes

None

### Classes

EditorKeywordsPage | Class implementing the editor highlighter keywords configuration page.

### Functions

create | Module function to create the configuration page.

## EditorKeywordsPage

Class implementing the editor highlighter keywords configuration page.

### Derived from

ConfigurationPageBase, Ui_EditorKeywordsPage

### Class Attributes

MaxKeywordSets

### Class Methods

None

### Methods

EditorKeywordsPage | Constructor
__populateLanguages | Private method to populate the language selection box.
on_allDefaultButton_clicked | Private slot to set all keyword sets of the current language to default values.
on_defaultButton_clicked | Private slot to set the current keyword set to default values.
on_languageCombo_activated | Private slot to fill the keywords edit.
on_setSpinBox_valueChanged | Private slot to fill the keywords edit.
save | Public slot to save the editor highlighter keywords configuration.
setMode | Public method to perform mode dependent setups.

### Static Methods

None

#### EditorKeywordsPage (Constructor)

EditorKeywordsPage()

Constructor

#### EditorKeywordsPage.__populateLanguages

__populateLanguages(languages)

Private method to populate the language selection box.

languages (list of str)
  list of languages to include in the language selector

#### EditorKeywordsPage.on_allDefaultButton_clicked

on_allDefaultButton_clicked()

Private slot to set all keyword sets of the current language to default values.

#### EditorKeywordsPage.on_defaultButton_clicked

on_defaultButton_clicked()

Private slot to set the current keyword set to default values.

#### EditorKeywordsPage.on_languageCombo_activated

on_languageCombo_activated(index)

Private slot to fill the keywords edit.

index (int)
  index of the selected entry

#### EditorKeywordsPage.on_setSpinBox_valueChanged

on_setSpinBox_valueChanged(kwSet)

Private slot to fill the keywords edit.

kwSet (int)
  number of the selected keyword set

#### EditorKeywordsPage.save

save()

Public slot to save the editor highlighter keywords configuration.

#### EditorKeywordsPage.setMode

setMode(displayMode)

Public method to perform mode dependent setups.

displayMode (ConfigurationMode)
  mode of the configuration dialog

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationWidget)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up